/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.spark.ml.python

import java.nio.file.Paths

import org.apache.hadoop.fs.{Path => FSPath}

import org.apache.spark.sql.SparkSession


object MLUtil {

  def copyFileFromLocalToFs(localPath: String, destPath: String): Unit = {
    val sparkContext = SparkSession.getActiveSession.get.sparkContext

    val hadoopConf = sparkContext.hadoopConfiguration
    assert(
      Paths.get(destPath).isAbsolute,
      "Destination path must be an absolute path on cloud storage."
    )
    val destFSPath = new FSPath(destPath)
    val fs = destFSPath.getFileSystem(hadoopConf)

    fs.copyFromLocalFile(false, true, new FSPath(localPath), destFSPath)
  }

}
